#!/bin/bash
#
# Nom del script: linkat-stat-edc.sh
# Versió 1.0
# Autor: Joan de Gracia
#        Projecte Linkat
#        Àrea de Cultura Digital - Departament d'Educació
# Data: 2021/02/04
# Llicència GPL 3.0
# Dependències: nmap, dmidecode, virt-what, base64
#
if [ "$(ps aux |grep linkat-stat |grep HOURLY | wc -l )"  -gt 2 ]; then
   exit 0
fi
if [ "$(ps aux |grep linkat-stat |grep BOOT | wc -l )"  -gt 2 ]; then
   exit 0
fi
if [ "$(ps aux |grep linkat-stat |grep LOGON | wc -l )"  -gt 3 ]; then
   exit 0
fi
START=$1
OD=$(which od)
WAIT_TIME=5m
BASE_RANDOM_TIME=$2
MAX_RANDOM_TIME=$3
ESPERA=$($OD -A n -N 2 -t u2 /dev/urandom )
let 'ESPERA %= MAX_RANDOM_TIME' # mòdul
let 'ESPERA += BASE_RANDOM_TIME'
sleep $ESPERA
ID_MACHINE="$(/usr/sbin/dmidecode -s system-uuid | sha1sum | cut -d " " -f 1)"
SN_MACHINE="$(/usr/sbin/dmidecode -s system-serial-number | cut -d " " -f 1)"
VERSION="$(/usr/bin/lsb_release -r| sed -e 's/\t//g' |cut -d ":" -f 2)"
VERSIOMQ="$(grep -i versiomq /etc/environment | sed 's/\"//g' |cut -d "=" -f 2)"
if [ "$VERSIOMQ" == "" ]; then
   VERSIOMQ="EMPTY"
fi
ARCH="$(uname -m)"
if [ "$ARCH" == "x86_64" ]; then
   ARCH="x86-64"
else
   ARCH="i386"
fi

if [ "$VERSION" == "14.04" ] || [ "$VERSION" == "18.04" ]; then
   COMPUTER="$(LANG=C apt list linkat-server linkat-servidor 2>/dev/null |grep -i "instal\|upgra" |cut -d "/" -f 1)"
   if [ -z "$COMPUTER" ]; then
      COMPUTER="workstation"
   else
      COMPUTER="server" 
   fi 
else
   COMPUTER="workstation"
fi

VIRT="$(/usr/sbin/virt-what |head -n1)"
VIRTUALIZATION="$(echo "$VIRT" | sed 's/[ ]\+/-/g')"
if [ -z "$VIRT" ]; then
   VIRTUALIZATION="physical"
fi
URL="download-linkat.xtec.cat"
CADENA="STAT-EDC-$1"
UBUNTU_DESKTOP="$(LANG=C apt list *ubuntu-desktop 2>/dev/null |grep -i "instal\|upgra" |cut -d "/" -f 1)"
case $UBUNTU_DESKTOP in
ubuntu-desktop)
   LINKAT_DESKTOP="gnome"
   LK_USER=$(ps aux |grep -i gnome-session-binary |grep -v grep | tr -s " " | cut -d " " -f 1)
;;
lubuntu-desktop)
   LINKAT_DESKTOP="lxde"
   LK_USER=$(ps aux|grep -i lxsession | grep -i lubuntu |grep -v ssh | tr -s " " | cut -d " " -f 1)
;;
esac

if [ "$LK_USER" == "" ] || [ "$LK_USER" == "0" ]; then
   LK_USERB64="root"
else
   LK_USERB64=$(echo "$LK_USER"|base64)
fi
if [ "$SN_MACHINE" == "" ] || [ "$SN_MACHINE" == "0" ]; then
   SN_MACHINEB64="0"
else 
   SN_MACHINEB64=$(echo "$SN_MACHINE"|base64)
fi
#
# Checking Network Connectivity
#
FLAG=0
TEST_IPS="educaciodigital.cat ubuntu.com wikipedia.org"
TARGET=($(echo $TEST_IPS))
N_TARGET=${#TARGET[@]}
let 'N_TARGET -=1'
TEST_PORT=443
CURRENT_TEST_IP=0
while [ $FLAG -eq 0 ];
do
   TESTIP=${TARGET[$CURRENT_TEST_IP]}
   if [ -z "$(nmap  -p $TEST_PORT $TESTIP  2>/dev/null |grep open)" ]; then
      if [ $CURRENT_TEST_IP -lt $N_TARGET ]; then   
   	   let 'CURRENT_TEST_IP +=1'
   	else
   	   CURRENT_TEST_IP=0
         sleep $WAIT_TIME
      fi
   else
      FLAG=1
   fi
done
curl -s $URL/"${CADENA}"_"${ID_MACHINE}"_"${LK_USERB64}"_"${SN_MACHINEB64}"_"${VERSIOMQ}"_"${VERSION}"_"${LINKAT_DESKTOP}"_"${ARCH}"_"${COMPUTER}"_"${VIRTUALIZATION}" -o /dev/null
exit 0
